@@ -9,9 +9,10 @@ Implementation based on RFC 5804.
 """
 
 import base64
+from functools import wraps
 import re
 import socket
-import ssl
+import ssl as ssllib
 from typing import Any, List, Optional, Tuple
 
 from .digest_md5 import DigestMD5
@@ -30,7 +31,7 @@ KNOWN_CAPABILITIES = [
     "VERSION",
 ]
 
-SUPPORTED_AUTH_MECHS = ["DIGEST-MD5", "PLAIN", "LOGIN", "OAUTHBEARER"]
+SUPPORTED_AUTH_MECHS = ["DIGEST-MD5", "PLAIN", "LOGIN", "OAUTHBEARER", "XOAUTH2"]
 
 
 class Error(Exception):
@@ -62,6 +63,7 @@ def authentication_required(meth):
     :param meth: the original called method
     """
 
+    @wraps(meth)
     def check(cls, *args, **kwargs):
         if cls.authenticated:
             return meth(cls, *args, **kwargs)
@@ -125,7 +127,7 @@ class Client:
             return buf
         try:
             buf += self.sock.recv(size)
-        except (socket.timeout, ssl.SSLError):
+        except (socket.timeout, ssllib.SSLError):
             raise Error("Failed to read %d bytes from the server" % size)
         self.__dprint(buf)
         return buf
@@ -160,7 +162,7 @@ class Client:
                 if not len(nval):
                     break
                 self.__read_buffer += nval
-            except (socket.timeout, ssl.SSLError):
+            except (socket.timeout, ssllib.SSLError):
                 raise Error("Failed to read data from the server")
 
         if len(ret):
@@ -181,7 +183,7 @@ class Client:
         """Read a response from the server.
 
         In the usual case, we read lines until we find one that looks
-        like a response (OK|NO|BYE\s*(.+)?).
+        like a response (OK|NO|BYE\\s*(.+)?).
 
         If *nblines* > 0, we read excactly nblines before returning.
 
@@ -217,7 +219,7 @@ class Client:
         """Format command arguments before sending them.
 
         Command arguments of type string must be quoted, the only
-        exception concerns size indication (of the form {\d\+?}).
+        exception concerns size indication (of the form {\\d\\+?}).
 
         :param args: list of arguments
         :return: a list for transformed arguments
@@ -312,7 +314,7 @@ class Client:
         if text corresponds to a size indication, we grab the
         remaining content from the server.
 
-        Otherwise, we try to match an error of the form \(\w+\)?\s*".+"
+        Otherwise, we try to match an error of the form \\(\\w+\\)?\\s*".+"
 
         On succes, the two public members errcode and errmsg are
         filled with the parsing results.
@@ -419,6 +421,27 @@ class Client:
             return True
         return False
 
+    def _xoauth2_authentication(
+        self, login: bytes, password: bytes, authz_id: bytes = b""
+    ) -> bool:
+        """
+        OAUTHBEARER authentication.
+
+        :param login: username
+        :param password: access token
+        :return: True on success, False otherwise.
+        """
+        if isinstance(login, str):
+            login = login.encode("utf-8")
+        if isinstance(password, str):
+            password = password.encode("utf-8")
+        token = b"user=" + login + b",\001auth=Bearer " + password + b"\001\001"
+        token = base64.b64encode(token)
+        code, data = self.__send_command("AUTHENTICATE", [b"XOAUTH2", token])
+        if code == "OK":
+            return True
+        return False
+
     def __authenticate(
         self,
         login: str,
@@ -467,7 +490,20 @@ class Client:
         self.errmsg = b"No suitable mechanism found"
         return False
 
-    def __starttls(self, keyfile=None, certfile=None) -> bool:
+    def __enable_ssl(
+        self, keyfile: Optional[str] = None, certfile: Optional[str] = None
+    ):
+        """Enable encryption for current socket."""
+        context = ssllib.create_default_context()
+        if certfile is not None:
+            context.load_cert_chain(certfile, keyfile=keyfile)
+        try:
+            nsock = context.wrap_socket(self.sock, server_hostname=self.srvaddr)
+        except ssllib.SSLError as e:
+            raise Error("SSL error: %s" % str(e))
+        self.sock = nsock
+
+    def __starttls(self, **kwargs) -> bool:
         """STARTTLS command
 
         See MANAGESIEVE specifications, section 2.2.
@@ -481,15 +517,7 @@ class Client:
         code, data = self.__send_command("STARTTLS")
         if code != "OK":
             return False
-        context = ssl.create_default_context()
-        if certfile is not None:
-            context.load_cert_chain(certfile, keyfile=keyfile)
-        try:
-            # nsock = ssl.wrap_socket(self.sock, keyfile, certfile)
-            nsock = context.wrap_socket(self.sock, server_hostname=self.srvaddr)
-        except ssl.SSLError as e:
-            raise Error("SSL error: %s" % str(e))
-        self.sock = nsock
+        self.__enable_ssl(**kwargs)
         self.__capabilities = {}
         self.__get_capabilities()
         return True
@@ -542,6 +570,7 @@ class Client:
         password: str,
         authz_id: str = "",
         starttls: bool = False,
+        ssl: bool = False,
         authmech: Optional[str] = None,
     ):
         """Establish a connection with the server.
@@ -552,6 +581,7 @@ class Client:
         :param login: username
         :param password: clear password
         :param starttls: use a TLS connection or not
+        :param ssl: use implict TLS/SSL when connecting
         :param authmech: prefered authenticate mechanism
         :rtype: boolean
         """
@@ -561,9 +591,12 @@ class Client:
         except socket.error as msg:
             raise Error("Connection to server failed: %s" % str(msg))
 
+        if ssl:
+            self.__enable_ssl()
+
         if not self.__get_capabilities():
             raise Error("Failed to read capabilities from server")
-        if starttls and not self.__starttls():
+        if not ssl and starttls and not self.__starttls():
             return False
         if self.__authenticate(login, password, authz_id, authmech):
             return True
